@@ -1,11 +1,7 @@
 from dbt.adapters.base import AdapterPlugin
 
-from dbt.adapters.firebolt.connections import (
-    FireboltConnectionManager,
-    FireboltCredentials,
-)
+from dbt.adapters.firebolt.connections import FireboltCredentials
 from dbt.adapters.firebolt.impl import FireboltAdapter
-from dbt.adapters.firebolt.relation import FireboltRelation
 from dbt.include import firebolt
 
 Plugin = AdapterPlugin(
